@@ -377,9 +377,6 @@ static int new_ad_header(struct adouble *ad, const char *path, struct stat *stp,
         LOG(log_debug, logtype_ad, "new_ad_header(\"%s\"): invalid FinderInfo", path);
         return -1;
     }
-    /* set default creator/type fields */
-    memcpy(adp + FINDERINFO_FRTYPEOFF,"\0\0\0\0", 4);
-    memcpy(adp + FINDERINFO_FRCREATOFF,"\0\0\0\0", 4);
 
     /* make things invisible */
     if ((ad->ad_options & ADVOL_INVDOTS)
