@@ -147,7 +147,7 @@ static char *get_vol_uuid(const AFPObj *obj, const char *volname)
     lock.l_len = 0;
     lock.l_whence = SEEK_SET;
 
-    fp = fopen(obj->options.uuidconf, "r+");
+    fp = fopen(obj->options.uuidconf, "r");
     if (fp != NULL) {
         /* Lock the file */
         lock.l_type = F_RDLCK;
@@ -208,6 +208,9 @@ static char *get_vol_uuid(const AFPObj *obj, const char *volname)
                 return strdup(uuid);
             }
         }
+        /* entry not found. reopen the file in read-write mode */
+        fclose(fp);
+        fp = fopen(obj->options.uuidconf, "r+");
     }
 
     if (fp == NULL) {
@@ -1022,8 +1025,10 @@ static struct vol *creatvol(AFPObj *obj,
             || accessvol(obj, getoption(obj->iniconfig, section, "rwlist", preset, NULL), pwd->pw_name) == 0)
             volume->v_flags |= AFPVOL_RO;
     }
+#ifndef WITH_TESTS
     if (0 == strcmp(volume->v_cnidscheme, "last"))
         volume->v_flags |= AFPVOL_RO;
+#endif
 
     if ((volume->v_flags & AFPVOL_NODEV))
         volume->v_ad_options |= ADVOL_NODEV;
@@ -1550,7 +1555,7 @@ void volume_unlink(struct vol *volume)
  * Free all resources allocated in a struct vol in load_volumes()
  *
  * Actually opening a volume (afp_openvol()) will allocate additional
- * ressources which are freed in closevol()
+ * resources which are freed in closevol()
  */
 void volume_free(struct vol *vol)
 {
@@ -2125,6 +2130,7 @@ int afp_config_parse(AFPObj *AFPObj, char *processname)
     options->ntdomain       = atalk_iniparser_getstrdup(config, INISEC_GLOBAL, "nt domain",      NULL);
     options->addomain       = atalk_iniparser_getstrdup(config, INISEC_GLOBAL, "ad domain",      NULL);
     options->ntseparator    = atalk_iniparser_getstrdup(config, INISEC_GLOBAL, "nt separator",   NULL);
+    options->legacyicon     = atalk_iniparser_getstrdup(config, INISEC_GLOBAL, "legacy icon",    "");
     options->mimicmodel     = atalk_iniparser_getstrdup(config, INISEC_GLOBAL, "mimic model",    NULL);
     options->zeroconfname    = atalk_iniparser_getstrdup(config, INISEC_GLOBAL, "zeroconf name",    NULL);
     options->adminauthuser  = atalk_iniparser_getstrdup(config, INISEC_GLOBAL, "admin auth user",NULL);
@@ -2370,6 +2376,8 @@ void afp_config_free(AFPObj *obj)
         CONFIG_ARG_FREE(obj->options.addomain);
     if (obj->options.ntseparator)
         CONFIG_ARG_FREE(obj->options.ntseparator);
+    if (obj->options.legacyicon)
+        CONFIG_ARG_FREE(obj->options.legacyicon);
     if (obj->options.mimicmodel)
         CONFIG_ARG_FREE(obj->options.mimicmodel);
     if (obj->options.zeroconfname)
