@@ -16,26 +16,26 @@
 #include "config.h"
 #endif /* HAVE_CONFIG_H */
 
-#include <unistd.h>
-#include <stdint.h>
+#include <arpa/inet.h>
+#include <dirent.h>
 #include <errno.h>
+#include <fcntl.h>
+#include <stdint.h>
 #include <stdlib.h>
 #include <string.h>
-#include <sys/types.h>
 #include <sys/stat.h>
-#include <fcntl.h>
-#include <dirent.h>
-#include <arpa/inet.h>
+#include <sys/types.h>
+#include <unistd.h>
 
 #include <atalk/adouble.h>
-#include <atalk/ea.h>
 #include <atalk/afp.h>
-#include <atalk/logger.h>
-#include <atalk/volume.h>
-#include <atalk/vfs.h>
-#include <atalk/util.h>
-#include <atalk/unix.h>
 #include <atalk/compat.h>
+#include <atalk/ea.h>
+#include <atalk/logger.h>
+#include <atalk/unix.h>
+#include <atalk/util.h>
+#include <atalk/vfs.h>
+#include <atalk/volume.h>
 
 /**********************************************************************************
  * EA VFS funcs for storing EAs in nativa filesystem EAs
@@ -82,7 +82,7 @@ int sys_get_easize(VFS_FUNC_ARGS_EA_GETSIZE)
     }
     /* PBaranski fix */
 
-    
+
     if (ret == -1) {
         memset(rbuf, 0, 4);
         *rbuflen += 4;
@@ -104,7 +104,7 @@ int sys_get_easize(VFS_FUNC_ARGS_EA_GETSIZE)
         }
     }
 
-    if (ret > MAX_EA_SIZE) 
+    if (ret > MAX_EA_SIZE)
       ret = MAX_EA_SIZE;
 
     if (vol->v_flags & AFPVOL_EA_SAMBA) {
@@ -160,7 +160,7 @@ int sys_get_eacontent(VFS_FUNC_ARGS_EA_GETCONTENT)
     uint32_t  attrsize;
     size_t    extra = 0;
 
-#ifdef SOLARIS
+#if defined(SOLARIS) && defined(HAVE_SYS_ATTR_H)
     /* Protect special attributes set by NFS server */
     if (!strcmp(attruname, VIEW_READONLY) || !strcmp(attruname, VIEW_READWRITE))
         return AFPERR_ACCESS;
@@ -280,7 +280,7 @@ int sys_list_eas(VFS_FUNC_ARGS_EA_LIST)
     int     ret, len, nlen;
     char    *buf;
     char    *ptr;
-    struct adouble ad, *adp;
+    struct adouble ad _U_, *adp _U_;
 
     buf = malloc(ATTRNAMEBUFSIZ);
     if (!buf)
@@ -311,7 +311,7 @@ int sys_list_eas(VFS_FUNC_ARGS_EA_LIST)
             ret = AFPERR_MISC;
             goto exit;
     }
-    
+
     ptr = buf;
     while (ret > 0)  {
         len = strlen(ptr);
@@ -371,7 +371,7 @@ int sys_set_ea(VFS_FUNC_ARGS_EA_SET)
     int ret;
     char *eabuf;
 
-#ifdef SOLARIS
+#if defined(SOLARIS) && defined(HAVE_SYS_ATTR_H)
     /* Protect special attributes set by NFS server */
     if (!strcmp(attruname, VIEW_READONLY) || !strcmp(attruname, VIEW_READWRITE))
         return AFPERR_ACCESS;
@@ -393,9 +393,9 @@ int sys_set_ea(VFS_FUNC_ARGS_EA_SET)
     eabuf[attrsize] = 0;
 
     attr_flag = 0;
-    if ((oflag & O_CREAT) ) 
+    if ((oflag & O_CREAT) )
         attr_flag |= XATTR_CREATE;
-    else if ((oflag & O_TRUNC) ) 
+    else if ((oflag & O_TRUNC) )
         attr_flag |= XATTR_REPLACE;
 
     if (vol->v_flags & AFPVOL_EA_SAMBA) {
@@ -434,7 +434,7 @@ int sys_set_ea(VFS_FUNC_ARGS_EA_SET)
             return AFPERR_MISC;
         default:
             LOG(log_debug, logtype_afpd, "sys_set_ea(\"%s/%s\", ea:'%s', size: %u, flags: %s|%s|%s): %s",
-                getcwdpath(), uname, attruname, attrsize, 
+                getcwdpath(), uname, attruname, attrsize,
                 oflag & O_CREAT ? "XATTR_CREATE" : "-",
                 oflag & O_TRUNC ? "XATTR_REPLACE" : "-",
                 oflag & O_NOFOLLOW ? "O_NOFOLLOW" : "-",
@@ -469,7 +469,7 @@ int sys_remove_ea(VFS_FUNC_ARGS_EA_REMOVE)
 {
     int ret;
 
-#ifdef SOLARIS
+#if defined(SOLARIS) && defined(HAVE_SYS_ATTR_H)
     /* Protect special attributes set by NFS server */
     if (!strcmp(attruname, VIEW_READONLY) || !strcmp(attruname, VIEW_READWRITE))
         return AFPERR_ACCESS;
@@ -592,7 +592,7 @@ int sys_ea_copyfile(VFS_FUNC_ARGS_COPYFILE)
         if (STRCMP(name, ==, AD_EA_META))
             continue;
 
-#ifdef SOLARIS
+#if defined(SOLARIS) && defined(HAVE_SYS_ATTR_H)
         /* Skip special attributes set by NFS server */
         if (!strcmp(name, VIEW_READONLY) || !strcmp(name, VIEW_READWRITE))
             continue;
@@ -658,7 +658,7 @@ int sys_ea_copyfile(VFS_FUNC_ARGS_COPYFILE)
 getout:
     if (cwd != -1)
         close(cwd);
-        
+
 	free(value);
 	free(names);
 
